@@ -170,6 +170,7 @@ class Window(Gtk.Window):
 
         self._buf.connect("mark-set", self.move_cursor_cb, None)
         self._view.connect("line-mark-activated", self.line_mark_activated, None)
+        self._buffer.connect("bracket-matched", self.bracket_matched, None);
 
     def insert_menu(self):
         action_group = Gtk.ActionGroup()
@@ -375,16 +376,16 @@ class Window(Gtk.Window):
         if dialog.run_search():
             i = self._buf.get_iter_at_mark(self._buf.get_insert())
 
-            searched, start, end = GtkSource.iter_forward_search(i, dialog.get_search_text(),
-                                                                 search_flags, None)
+            searched, start, end = i.forward_search(dialog.get_search_text(),
+                                                    search_flags, None)
             if searched:
                 self._buf.select_range(start, end)
             else:
                 end = i
                 i = self._buf.get_start_iter()
 
-                searched, start, end = GtkSource.iter_forward_search(i, dialog.get_search_text(),
-                                                                     search_flags, end)
+                searched, start, end = i.forward_search(dialog.get_search_text(),
+                                                        search_flags, end)
                 if searched:
                     self._buf.select_range(start, end)
 
@@ -399,8 +400,8 @@ class Window(Gtk.Window):
         i = self._buf.get_start_iter()
 
         while True:
-            searched, start, end = GtkSource.iter_forward_search(i, dialog.get_search_text(),
-                                                                 search_flags, None)
+            searched, start, end = i.forward_search(dialog.get_search_text(),
+                                                    search_flags, None)
 
             if not searched:
                 break
@@ -506,6 +507,15 @@ class Window(Gtk.Window):
         else:
             self._buf.create_source_mark(None, mark_type, place)
 
+    def bracket_matched(self, place, state, user_data):
+        # FIXME: figure out how to obtain the nick from the enum value
+        # print "Bracket match state: '%s'\n" % nick
+        if state == GtkSource.BracketMatchType.FOUND:
+            bracket = place.get_char()
+            row = place.get_line() + 1
+            col = place.get_line_offset() + 1
+            print "Matched bracket: '%c' at row: %i, col: %i\n" % bracket % row % col
+
     def open_file(self, filename):
         if os.path.isabs(filename):
             path = filename
